@@ -70,7 +70,7 @@ void thread::publish(void)
 	if(destination != LOCAL)
 		goto final;
 
-	if(!reginfo || reginfo->type != MappedRegistry::USER)
+	if(!reginfo || !reginfo->isUser())
 		goto final;
 
 	if(!String::equal(reginfo->userid, identity))
@@ -783,7 +783,7 @@ rewrite:
 		}
 		if(!stricmp(dialed.keys->getId(), "queue"))
 			goto anonymous;
-		if(!stricmp(dialed.keys->getId(), "user")) {
+		if(!stricmp(dialed.keys->getId(), "user") || !stricmp(dialed.keys->getId(), "admin")) {
 			if(MSG_IS_MESSAGE(sevent->request))
 				goto trying;
 			process::errlog(NOTIFY, "unregistered destination %s", target);
@@ -815,6 +815,9 @@ rewrite:
 	}
 
 trying:
+	if(MSG_IS_PUBLISH(sevent->request))
+		return authenticate();
+
 	// extension references always require authentication
 	if(registry::isExtension(target)) {
 		if(!authenticate())
@@ -824,8 +827,26 @@ trying:
 		return true;
 	}
 
-	if(reginfo && reginfo->type == MappedRegistry::USER && (reginfo->profile.features & USER_PROFILE_INCOMING))
+	// see if destination allows anonymous remote (public) callers
+
+	if(reginfo && reginfo->isFeature(USER_PROFILE_INCOMING) && from->url->host) {
+
+		// now we make sure the originating call does not "claim" to be
+		// associated with us.  If it has any of our our names, then we have
+		// the inbound caller authenticate like any local-to-local call
+
+		if(String::equal(stack::sip.domain, from->url->host))
+			return authenticate();
+
+		if(String::equal("localdomain", from->url->host))
+			return authenticate();
+
+		if(String::ifind(stack::sip.localnames, from->url->host, " ,;:\t\n"))
+			return authenticate();
+
+		// It "seems" external, user allows incoming, handle as public
 		goto anonymous;
+	}
 
 	return authenticate();
 
@@ -991,7 +1012,7 @@ remote:
 	if(!reginfo || (reginfo->expires && reginfo->expires < now))
 		goto invalid;
 
-	if(reginfo->type == MappedRegistry::USER && !(reginfo->profile.features & USER_PROFILE_OUTGOING))
+	if(!reginfo->isFeature(USER_PROFILE_OUTGOING))
 		goto invalid;
 
 	refer = server::referRemote(reginfo, requesting, buffer, sizeof(buffer));
@@ -1552,7 +1573,7 @@ void thread::reregister(const char *contact, time_t interval)
 
 	refresh = reginfo->refresh(contact_address, expire, contact);
 	if(!refresh) {
-		if(reginfo->type == MappedRegistry::USER && (reginfo->profile.features & USER_PROFILE_MULTITARGET))
+		if(reginfo->type == MappedRegistry::USER)
 			count = reginfo->addTarget(contact_address, expire, contact, network, (struct sockaddr *)&peering);
 		else
 			count = reginfo->setTarget(contact_address, expire, contact, network, (struct sockaddr *)&peering);
@@ -1593,7 +1614,7 @@ reply:
 	else
 		eXosip_message_send_answer(sevent->tid, SIP_BAD_REQUEST, NULL);
 	eXosip_unlock();
-	if(reginfo && reginfo->type == MappedRegistry::USER && answer == SIP_OK)
+	if(reginfo && reginfo->isUser() && answer == SIP_OK)
 		messages::update(identity);
 }
 
